@@ -1,18 +1,18 @@
 import os
 
 
-def output(value, newline=False):
+def output(value, sep='-----'):
     """
-    输出变量
+    输出变量信息
 
     :param value: 变量
-    :param newline: 是否换行
+    :param sep: 分隔符
     :return:
     """
-    if newline:
-        print(f'表达式：{repr(value)} \n类型：{type(value)} \n值：{value}')
+    if sep == '\n':
+        print(f'表达式：{repr(value)} {sep}类型：{type(value)} {sep}值：{value}')
     else:
-        print(f'表达式：{repr(value)} ----- 类型：{type(value)} ----- 值：{value}')
+        print(f'表达式：{repr(value)} {sep} 类型：{type(value)} {sep} 值：{value}')
 
 
 def create_dir(dir_path):
